<img src="https://raw.githubusercontent.com/shikijs/shiki/main/docs/public/logo.svg" width="150" alt="Shiki Logo" />

# Shiki 式

[![NPM version](https://img.shields.io/npm/v/shiki?color=32A9C3&labelColor=1B3C4A&label=npm)](https://www.npmjs.com/package/shiki)
[![NPM downloads](https://img.shields.io/npm/dm/shiki?color=32A9C3&labelColor=1B3C4A&label=downloads)](https://www.npmjs.com/package/shiki)
[![Codecov](https://img.shields.io/codecov/c/github/shikijs/shiki?token=B85J0E2I7I&style=flat&labelColor=1B3C4A&color=32A9C3&precision=1)](https://app.codecov.io/gh/shikijs/shiki)

A beautiful syntax highlighter based on TextMate grammars, accurate and powerful.

[📚 **Documentation**](https://shiki.style)

## License

[MIT](./LICENSE)
